@@ -239,6 +239,11 @@ class SamFileType(enum.Enum):
     BAM = ("b", ".bam")
     CRAM = ("c", ".cram")
 
+    @property
+    def indexable(self) -> bool:
+        """True if the file type can be indexed, false otherwise."""
+        return self is SamFileType.BAM or self is SamFileType.CRAM
+
     @classmethod
     def from_path(cls, path: Union[Path, str]) -> "SamFileType":
         """Infers the file type based on the file extension.
@@ -253,7 +258,7 @@ class SamFileType(enum.Enum):
             raise ValueError(f"Could not infer file type from {path}") from ex
 
 
-def _pysam_open(
+def _pysam_open(  # noqa: C901
     path: SamPath,
     open_for_reading: bool,
     file_type: Optional[SamFileType] = None,
@@ -306,9 +311,24 @@ def _pysam_open(
     if unmapped and open_for_reading:
         kwargs["check_sq"] = False
 
-    # Open it alignment file, suppressing stderr in case index files are older than SAM file
-    with fgpyo.io.suppress_stderr():
-        alignment_file = pysam.AlignmentFile(path, **kwargs)
+    # Open the alignment file, suppressing stderr in case index files are older than the SAM/BAM.
+    try:
+        with fgpyo.io.suppress_stderr():
+            alignment_file = pysam.AlignmentFile(path, **kwargs)
+    except (ValueError, OSError) as ex:
+        msg = str(ex).lower()
+        if (
+            ("check_sq=false" in msg)
+            or ("no sq" in msg)
+            or ("no @sq" in msg)
+            or ("sequence dictionary" in msg and "missing" in msg)
+        ):
+            raise ValueError(
+                f"No sequence dictionary found (@SQ header lines missing). Path: {path!r}. "
+                "If this file is unmapped, open with unmapped=True (sets check_sq=False)."
+            ) from ex
+        raise
+
     # now restore stderr and return the alignment file
     return alignment_file
 
@@ -607,24 +627,6 @@ class Cigar:
             raise ValueError(f"Cigar {self} has no aligned bases")
         return start_offset, end_offset
 
-    def __getitem__(
-        self, index: Union[int, slice]
-    ) -> Union[CigarElement, Tuple[CigarElement, ...]]:
-        """Returns the cigar element indexed by index
-
-        Arguments:
-            index: int The index of the requested cigar element(s)
-
-        Returns: CigarElement or Tuple[CigarElement,...]
-            The element(s) selected by index
-
-        Throws:
-            TypeError if index isn't an integer or a slice
-            IndexError: if there's no such element
-
-        """
-        return self.elements[index]
-
 
 @enum.unique
 class PairOrientation(enum.Enum):
